'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-8c024524.js');
const utils = require('./utils-73fcae00.js');

class revealY {
  static show(element) {
    return element === null || element === void 0 ? void 0 : element.animate([{ transform: "scaleY(0)" }, { transform: "scaleY(1)" }], { duration: 250 });
  }
  static hide(element) {
    return element === null || element === void 0 ? void 0 : element.animate([{ transform: "scaleY(1)" }, { transform: "scaleY(0)" }], {
      duration: 250
    });
  }
}

const darkShadowCss = ".dark-shadow-container{top:0;left:0;right:0;bottom:0;width:100%;height:100%;display:-ms-flexbox;display:flex;z-index:9999;position:fixed;-ms-flex-align:center;align-items:center;-ms-flex-pack:center;justify-content:center}.dark-shadow-container--hidden{display:none}.dark-shadow-container--dark-outside{background-color:rgba(0, 0, 0, 0.5)}.dark-shadow{display:none;padding:0.8rem;max-height:90%;color:var(--color-font);background-color:var(--color-primary, white)}.dark-shadow--visible{display:-ms-flexbox;display:flex}.dark-shadow-content{width:100%}.dark-shadow-header--has-title{padding-bottom:0.5rem}.dark-shadow-header__title{margin-top:0;margin-bottom:0}.dark-shadow-header i{float:right;cursor:pointer}.dark-shadow-header__clear-svg{width:1.2rem;height:1.2rem;vertical-align:middle;fill:var(--color-font)}.dark-shadow-body{overflow:auto;max-height:82%;margin-top:1rem}.dark-shadow-footer{float:right;margin-top:1.5rem}.dark-shadow-footer *{margin-left:0.5rem}";

let DarkShadow = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.beforeShowCallback = index.createEvent(this, "beforeShowCallback", 7);
    this.afterShowCallback = index.createEvent(this, "afterShowCallback", 7);
    this.beforeHideCallback = index.createEvent(this, "beforeHideCallback", 7);
    this.afterHideCallback = index.createEvent(this, "afterHideCallback", 7);
    this.isDarkOutside = true;
    this.width = "auto";
    this.showCloseIcon = true;
    this.shadowTitle = "";
    this.animation = { open: null, close: null };
    this.closeOnOutsideClick = false;
    this.visible = false;
    this.extend = false;
    this.showDarkShadow = () => {
      var _a, _b, _c;
      const { returnValue } = this.beforeShowCallback.emit(this.el);
      if (returnValue) {
        this.extend = true;
        if (this.animation) {
          (_c = (_b = (_a = this.animation).open) === null || _b === void 0 ? void 0 : _b.call(_a, this.darkShadowElement)) !== null && _c !== void 0 ? _c : revealY.show(this.darkShadowElement);
        }
        if (this.closeOnOutsideClick) {
          document.addEventListener("keydown", this.handleKeyDown);
          this.el.addEventListener("click", this.handleOutsideClick);
          this.darkShadowElement.addEventListener("click", utils.stopClickPropagation);
        }
        this.afterShowCallback.emit(this.el);
      }
    };
    this.hideDarkShadow = () => {
      var _a, _b, _c;
      const { returnValue } = this.beforeHideCallback.emit(this.el);
      if (returnValue) {
        if (this.animation) {
          (_c = (_b = (_a = this.animation).close) === null || _b === void 0 ? void 0 : _b.call(_a, this.darkShadowElement)) !== null && _c !== void 0 ? _c : (revealY.hide(this.darkShadowElement).onfinish = () => {
            this.extend = false;
            this.afterHideCallback.emit(this.el);
          });
        }
        else {
          this.extend = false;
          this.afterHideCallback.emit(this.el);
        }
        if (this.closeOnOutsideClick) {
          document.removeEventListener("keydown", this.handleKeyDown);
          this.el.removeEventListener("click", this.handleOutsideClick);
          this.darkShadowElement.removeEventListener("click", utils.stopClickPropagation);
        }
      }
    };
    this.handleKeyDown = (ev) => {
      if (ev.key === "Escape") {
        this.close();
      }
    };
    this.handleOutsideClick = () => {
      this.close();
    };
  }
  get darkShadowElement() {
    return this.el.querySelector(".dark-shadow");
  }
  visiblePropWatcher() {
    if (this.visible) {
      this.showDarkShadow();
    }
    else {
      this.hideDarkShadow();
    }
  }
  async open() {
    this.visible = true;
  }
  async close() {
    this.visible = false;
  }
  animate(el, mode) {
    if (this.animation) {
      if (mode === "open") {
        this.animation.open(el);
      }
      else {
        this.animation.close(el);
      }
    }
  }
  componentDidRender() {
    this.visible && this.showDarkShadow();
  }
  render() {
    var _a;
    return (index.h("div", { class: {
        "dark-shadow-container": true,
        "dark-shadow-container--dark-outside": this.isDarkOutside,
        "dark-shadow-container--hidden": !this.extend,
      } }, index.h("div", { class: { "dark-shadow": true, "dark-shadow--visible": this.extend }, style: { width: this.width } }, index.h("div", { class: "dark-shadow-content" }, index.h("slot", { name: "header" }, index.h("div", { class: {
        "dark-shadow-header": true,
        "dark-shadow-header--has-title": this.showCloseIcon || ((_a = this.shadowTitle) === null || _a === void 0 ? void 0 : _a.length) > 0,
      } }, this.showCloseIcon ? (index.h("slot", { name: "header-close-icon" }, index.h("i", { class: "dark-shadow-header__close-icon", onClick: this.close.bind(this) }, index.h("svg", { class: "dark-shadow-header__clear-svg", viewBox: "0 0 24 24" }, index.h("path", { d: "M18.984 6.422l-5.578 5.578 5.578 5.578-1.406 1.406-5.578-5.578-5.578 5.578-1.406-1.406 5.578-5.578-5.578-5.578 1.406-1.406 5.578 5.578 5.578-5.578z" }))))) : null, index.h("h2", { class: "dark-shadow-header__title" }, this.shadowTitle))), index.h("slot", { name: "body" }, index.h("div", { class: "dark-shadow-body" }, index.h("slot", null))), index.h("slot", { name: "footer" }, index.h("div", { class: "dark-shadow-footer" }, index.h("slot", { name: "footer-content" })))))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "visible": ["visiblePropWatcher"]
  }; }
};
DarkShadow.style = darkShadowCss;

exports.dark_shadow = DarkShadow;
