'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-8c024524.js');
const hover = require('./hover-f950f401.js');

class Ripple {
  static doRipple(e) {
    const { left, top } = this.getBoundingClientRect();
    const x = e.pageX - left;
    const y = e.pageY - top;
    const w = this.offsetWidth;
    const ripple = document.createElement("span");
    ripple.className = "one-for-all-ripple--ripple-element";
    ripple.style.left = x + "px";
    ripple.style.top = y + "px";
    ripple.style.setProperty("--scale", w.toString());
    this.appendChild(ripple);
    setTimeout(() => {
      ripple.parentNode.removeChild(ripple);
    }, 500);
  }
  static observe(element) {
    element.addEventListener("mousedown", this.doRipple);
  }
  static destroy(element) {
    element.removeEventListener("mousedown", this.doRipple);
  }
}

const zeroGravityButtonCss = ".zero-gravity-button{padding:0;outline:0;z-index:1;width:56px;height:56px;cursor:pointer;border-style:none;-ms-flex-align:center;align-items:center;display:-ms-inline-flexbox;display:inline-flex;vertical-align:middle;-ms-flex-pack:center;justify-content:center;color:var(--color-font);border-color:var(--color-primary, white);background-color:var(--color-primary, white);-webkit-transition:opacity 0.2s linear, -webkit-box-shadow 0.2s linear;transition:opacity 0.2s linear, -webkit-box-shadow 0.2s linear;transition:box-shadow 0.2s linear, opacity 0.2s linear;transition:box-shadow 0.2s linear, opacity 0.2s linear, -webkit-box-shadow 0.2s linear}.zero-gravity-button.size-small{width:40px;height:40px}.zero-gravity-button.size-medium{width:48px;height:48px}.zero-gravity-button.color-secondary{color:var(--color-font);border-color:var(--color-secondary);background-color:var(--color-secondary)}.zero-gravity-button.variant-extended{width:auto;padding:0 1rem;min-height:auto}.zero-gravity-button.top-left{left:1rem;top:1rem;position:absolute}.zero-gravity-button.top-center{left:50%;top:1rem;position:absolute}.zero-gravity-button.top-right{right:1rem;top:1rem;position:absolute}.zero-gravity-button.center-left{left:1rem;top:50%;position:absolute;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.zero-gravity-button.center-right{right:1rem;top:50%;position:absolute;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.zero-gravity-button.bottom-left{left:1rem;bottom:1rem;position:absolute}.zero-gravity-button.bottom-center{left:50%;bottom:1rem;position:absolute}.zero-gravity-button.bottom-right{right:1rem;bottom:1rem;position:absolute}.zero-gravity-button.top-left.size-large.overlap,.zero-gravity-button.top-right.size-large.overlap,.zero-gravity-button.top-center.size-large.overlap{top:-28px}.zero-gravity-button.top-left.size-medium.overlap,.zero-gravity-button.top-right.size-medium.overlap,.zero-gravity-button.top-center.size-medium.overlap{top:-24px}.zero-gravity-button.top-left.size-small.overlap,.zero-gravity-button.top-right.size-small.overlap,.zero-gravity-button.top-center.size-small.overlap{top:-20px}.zero-gravity-button.center-left.size-large.overlap{left:-28px}.zero-gravity-button.center-left.size-medium.overlap{left:-24px}.zero-gravity-button.center-left.size-small.overlap{left:-20px}.zero-gravity-button.center-right.size-large.overlap{right:-28px}.zero-gravity-button.center-right.size-medium.overlap{right:-24px}.zero-gravity-button.center-right.size-small.overlap{right:-20px}.zero-gravity-button.bottom-left.size-large.overlap,.zero-gravity-button.bottom-right.size-large.overlap,.zero-gravity-button.bottom-center.size-large.overlap{bottom:-28px}.zero-gravity-button.bottom-left.size-medium.overlap,.zero-gravity-button.bottom-right.size-medium.overlap,.zero-gravity-button.bottom-center.size-medium.overlap{bottom:-24px}.zero-gravity-button.bottom-left.size-small.overlap,.zero-gravity-button.bottom-right.size-small.overlap,.zero-gravity-button.bottom-center.size-small.overlap{bottom:-20px}";

let ZeroGravityButton = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.ripple = true;
    this.elevation = 2;
    this.overlap = false;
    this.hoverElevation = 0;
    this.variant = "round";
    this.color = "primary";
    this.size = "large";
    this.radius = this.variant.toLowerCase() === "round" ? "50%" : "26px";
    this.position = "custom";
    this.isHover = false;
    this.hoverEvent = new hover.HoverEvent((isHover) => {
      this.isHover = isHover;
    });
  }
  get ZeroGravityButtonEl() {
    return this.el.querySelector(".zero-gravity-button");
  }
  componentDidLoad() {
    this.hoverEvent.observe(this.ZeroGravityButtonEl);
    Ripple.observe(this.ZeroGravityButtonEl);
  }
  disconnectedCallback() {
    this.hoverEvent.stop(this.ZeroGravityButtonEl);
    Ripple.destroy(this.ZeroGravityButtonEl);
  }
  render() {
    return (index.h("button", { class: `zero-gravity-button one-for-all-ripple size-${this.size.toLowerCase()} one-for-all-elevation-${this.isHover && this.hoverElevation
        ? this.hoverElevation
        : this.elevation} color-${this.color.toLowerCase()} variant-${this.variant.toLowerCase()} ${this.position.toLowerCase()} ${this.overlap ? "overlap" : ""}`, type: "button", style: { borderRadius: this.radius } }, index.h("slot", null)));
  }
  get el() { return index.getElement(this); }
};
ZeroGravityButton.style = zeroGravityButtonCss;

exports.zero_gravity_button = ZeroGravityButton;
