import { Component, h, Prop, Watch, Element, Method, Event, State, } from "@stencil/core";
import { revealY } from "../../utils/animations";
import { stopClickPropagation } from "../../utils/utils";
export class DarkShadow {
  constructor() {
    this.isDarkOutside = true;
    this.width = "auto";
    this.showCloseIcon = true;
    this.shadowTitle = "";
    this.animation = { open: null, close: null };
    this.closeOnOutsideClick = false;
    this.visible = false;
    this.extend = false;
    this.showDarkShadow = () => {
      var _a, _b, _c;
      const { returnValue } = this.beforeShowCallback.emit(this.el);
      if (returnValue) {
        this.extend = true;
        if (this.animation) {
          (_c = (_b = (_a = this.animation).open) === null || _b === void 0 ? void 0 : _b.call(_a, this.darkShadowElement)) !== null && _c !== void 0 ? _c : revealY.show(this.darkShadowElement);
        }
        if (this.closeOnOutsideClick) {
          document.addEventListener("keydown", this.handleKeyDown);
          this.el.addEventListener("click", this.handleOutsideClick);
          this.darkShadowElement.addEventListener("click", stopClickPropagation);
        }
        this.afterShowCallback.emit(this.el);
      }
    };
    this.hideDarkShadow = () => {
      var _a, _b, _c;
      const { returnValue } = this.beforeHideCallback.emit(this.el);
      if (returnValue) {
        if (this.animation) {
          (_c = (_b = (_a = this.animation).close) === null || _b === void 0 ? void 0 : _b.call(_a, this.darkShadowElement)) !== null && _c !== void 0 ? _c : (revealY.hide(this.darkShadowElement).onfinish = () => {
            this.extend = false;
            this.afterHideCallback.emit(this.el);
          });
        }
        else {
          this.extend = false;
          this.afterHideCallback.emit(this.el);
        }
        if (this.closeOnOutsideClick) {
          document.removeEventListener("keydown", this.handleKeyDown);
          this.el.removeEventListener("click", this.handleOutsideClick);
          this.darkShadowElement.removeEventListener("click", stopClickPropagation);
        }
      }
    };
    this.handleKeyDown = (ev) => {
      if (ev.key === "Escape") {
        this.close();
      }
    };
    this.handleOutsideClick = () => {
      this.close();
    };
  }
  get darkShadowElement() {
    return this.el.querySelector(".dark-shadow");
  }
  visiblePropWatcher() {
    if (this.visible) {
      this.showDarkShadow();
    }
    else {
      this.hideDarkShadow();
    }
  }
  async open() {
    this.visible = true;
  }
  async close() {
    this.visible = false;
  }
  animate(el, mode) {
    if (this.animation) {
      if (mode === "open") {
        this.animation.open(el);
      }
      else {
        this.animation.close(el);
      }
    }
  }
  componentDidRender() {
    this.visible && this.showDarkShadow();
  }
  render() {
    var _a;
    return (h("div", { class: {
        "dark-shadow-container": true,
        "dark-shadow-container--dark-outside": this.isDarkOutside,
        "dark-shadow-container--hidden": !this.extend,
      } },
      h("div", { class: { "dark-shadow": true, "dark-shadow--visible": this.extend }, style: { width: this.width } },
        h("div", { class: "dark-shadow-content" },
          h("slot", { name: "header" },
            h("div", { class: {
                "dark-shadow-header": true,
                "dark-shadow-header--has-title": this.showCloseIcon || ((_a = this.shadowTitle) === null || _a === void 0 ? void 0 : _a.length) > 0,
              } },
              this.showCloseIcon ? (h("slot", { name: "header-close-icon" },
                h("i", { class: "dark-shadow-header__close-icon", onClick: this.close.bind(this) },
                  h("svg", { class: "dark-shadow-header__clear-svg", viewBox: "0 0 24 24" },
                    h("path", { d: "M18.984 6.422l-5.578 5.578 5.578 5.578-1.406 1.406-5.578-5.578-5.578 5.578-1.406-1.406 5.578-5.578-5.578-5.578 1.406-1.406 5.578 5.578 5.578-5.578z" }))))) : null,
              h("h2", { class: "dark-shadow-header__title" }, this.shadowTitle))),
          h("slot", { name: "body" },
            h("div", { class: "dark-shadow-body" },
              h("slot", null))),
          h("slot", { name: "footer" },
            h("div", { class: "dark-shadow-footer" },
              h("slot", { name: "footer-content" })))))));
  }
  static get is() { return "dark-shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dark-shadow.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dark-shadow.css"]
  }; }
  static get properties() { return {
    "isDarkOutside": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "is-dark-outside",
      "reflect": false,
      "defaultValue": "true"
    },
    "width": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "width",
      "reflect": false,
      "defaultValue": "\"auto\""
    },
    "showCloseIcon": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "show-close-icon",
      "reflect": false,
      "defaultValue": "true"
    },
    "shadowTitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "shadow-title",
      "reflect": false,
      "defaultValue": "\"\""
    },
    "animation": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "{ open: any; close: any; }",
        "resolved": "{ open: any; close: any; }",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "{ open: null, close: null }"
    },
    "closeOnOutsideClick": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "close-on-outside-click",
      "reflect": false,
      "defaultValue": "false"
    },
    "visible": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "visible",
      "reflect": true,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "extend": {}
  }; }
  static get events() { return [{
      "method": "beforeShowCallback",
      "name": "beforeShowCallback",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }, {
      "method": "afterShowCallback",
      "name": "afterShowCallback",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }, {
      "method": "beforeHideCallback",
      "name": "beforeHideCallback",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }, {
      "method": "afterHideCallback",
      "name": "afterHideCallback",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "open": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "close": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "visible",
      "methodName": "visiblePropWatcher"
    }]; }
}
