import { Component, h, Method, Prop, State, Element } from '@stencil/core';
import { isElementVisibleInViewportAndParent } from '../../utils/utils';
export class QuirkBoomerang {
  constructor() {
    this.moveCount = 1;
    this.totalElements = 0;
    this.displayCount = { small: "1", medium: "2", large: "4" };
    this.moveButtonInaccessibleBehaviour = "disable";
    this.visibleMoveButton = { forward: true, backward: false };
  }
  get quirkContainerEl() {
    return this.quirkEl.querySelector("quirk-boomerang .quirk-container");
  }
  get visibleQuirks() {
    return this.quirkContainerEl.querySelectorAll(".quirk-visible");
  }
  get quirkCount() {
    let count = 1;
    try {
      if (typeof this.displayCount === "object") {
        return this.displayCount;
      }
      if (isNaN(this.displayCount)) {
        return JSON.parse(this.displayCount);
      }
      else {
        count = +this.displayCount;
      }
    }
    catch (error) {
      console.warn("Set proper value for displayCount prop. Error: ", error);
    }
    return { small: count, medium: count, large: count };
  }
  get elementCount() {
    return (this.totalElements || document.querySelectorAll("quirk-boomerang .quirk-container > [quirk-index]").length);
  }
  get lastMovedElementIndex() {
    return this.lastMovedElement ? +this.lastMovedElement.getAttribute("quirk-index") : -1;
  }
  async moveQuirk(isMoveForward, moveElementIndex = undefined) {
    if (moveElementIndex) {
      this.moveDirection = moveElementIndex >= this.lastMovedElementIndex ? "forward" : "backward";
      isMoveForward = this.moveDirection === "forward";
    }
    else {
      this.moveDirection = isMoveForward ? "forward" : "backward";
    }
    // if (this.visibleQuirks && this.visibleQuirks.length && (!moveElementIndex || (moveElementIndex && moveElementIndex !== this.lastMovedElementIndex))) {
    if (this.visibleQuirks && this.visibleQuirks.length) {
      const currentEndIndex = +this.visibleQuirks[this.visibleQuirks.length - 1].getAttribute("quirk-index");
      const moveToIndex = moveElementIndex != null ? moveElementIndex
        : isMoveForward ? currentEndIndex + this.moveCount : currentEndIndex - this.moveCount;
      let moveEl = this.quirkContainerEl.querySelector(`[quirk-index="${moveToIndex}"]`) || this.quirkContainerEl.lastElementChild;
      if (this.lastMovedElement === moveEl) {
        moveEl = this.quirkContainerEl.querySelector(`[quirk-index="${moveToIndex + this.moveCount}"]`) || this.quirkContainerEl.lastElementChild;
      }
      if (moveEl) {
        this.lastMovedElement = moveEl;
        moveEl.scrollIntoView({ behavior: "smooth", block: "nearest", inline: "end" });
      }
    }
  }
  setVisibleQuirks() {
    let visibleQuirkClassSetFailCount = 0;
    const isFirstRender = this.lastMovedElement == null;
    const lastMoveElementIndex = isFirstRender ? 0 : +this.lastMovedElement.getAttribute("quirk-index");
    const isVisibleQuirksAvailable = this.visibleQuirks && this.visibleQuirks.length;
    const isMoveForward = this.moveDirection == null || this.moveDirection === "forward";
    const firstVisibleQuirkIndex = isFirstRender ? 0 : isVisibleQuirksAvailable
      ? +this.visibleQuirks[0].getAttribute("quirk-index")
      : lastMoveElementIndex;
    const lastVisibleQuirkIndex = isFirstRender ? this.moveCount : isVisibleQuirksAvailable
      ? +this.visibleQuirks[this.visibleQuirks.length - 1].getAttribute("quirk-index")
      : lastMoveElementIndex;
    let index = isMoveForward ? firstVisibleQuirkIndex : lastVisibleQuirkIndex;
    this.quirkContainerEl.querySelectorAll("[quirk-index]").forEach(quirk => quirk.classList.remove("quirk-visible"));
    while (true) {
      const el = this.quirkContainerEl.querySelector(`[quirk-index="${index}"]`);
      if (el && isElementVisibleInViewportAndParent(el, this.quirkEl.parentElement)) {
        el.classList.add("quirk-visible");
      }
      else {
        visibleQuirkClassSetFailCount++;
      }
      if (isMoveForward) {
        index++;
      }
      else {
        index--;
      }
      if (visibleQuirkClassSetFailCount > this.elementCount) {
        break;
      }
    }
    this.setMoveButtonVisibility(firstVisibleQuirkIndex, lastVisibleQuirkIndex, isFirstRender);
  }
  setMoveButtonVisibility(firstVisibleQuirkIndex, lastVisibleQuirkIndex, isFirstRender) {
    if (!isFirstRender) {
      this.visibleMoveButton = Object.assign(Object.assign({}, this.visibleMoveButton), { forward: lastVisibleQuirkIndex < this.elementCount - 1, backward: firstVisibleQuirkIndex > 0 });
    }
  }
  keyPressHandler(event) {
    if (event.key === "Tab" && document.activeElement && document.activeElement.getAttribute("quirk-index")) {
      let moveElementIndex = +document.activeElement.getAttribute("quirk-index");
      // here added 1 to make sure next element to focus is in view
      this.moveQuirk(undefined, moveElementIndex + 1);
    }
  }
  scrollEventCallback(_e) {
    if (this.scrollTimeoutId != null) {
      clearTimeout(this.scrollTimeoutId);
    }
    this.scrollTimeoutId = window.setTimeout(() => {
      this.setVisibleQuirks();
    }, 0);
  }
  componentDidLoad() {
    this.setVisibleQuirks();
  }
  componentDidRender() {
    this.quirkContainerEl.addEventListener('scroll', this.scrollEventCallback.bind(this));
  }
  disconnectedCallback() {
    this.quirkContainerEl.removeEventListener("scroll", this.scrollEventCallback.bind(this));
  }
  render() {
    return (h("div", { class: "quirk-boomerang-container" },
      h("div", { class: "move-btns", tabIndex: -1 },
        this.moveButtonInaccessibleBehaviour === "disable" || this.visibleMoveButton.backward ?
          h("slot", { name: "left-button" },
            h("div", { class: "move-btn-wrapper backward-move-btn-wrapper" },
              h("button", { class: "move-btn backward-move backward-move-btn", disabled: !this.visibleMoveButton.backward, onClick: this.moveQuirk.bind(this, false, undefined) }, "<")))
          : null,
        this.moveButtonInaccessibleBehaviour === "disable" || this.visibleMoveButton.forward ?
          h("slot", { name: "right-button" },
            h("div", { class: "move-btn-wrapper forward-move-btn-wrapper" },
              h("button", { class: "move-btn forward-move forward-move-btn", disabled: !this.visibleMoveButton.forward, onClick: this.moveQuirk.bind(this, true, undefined) }, ">")))
          : null),
      h("div", { class: "quirk-container", onKeyUp: this.keyPressHandler.bind(this), style: { "--quirk-small-count": this.quirkCount.small, "--quirk-medium-count": this.quirkCount.medium, "--quirk-large-count": this.quirkCount.large } },
        h("slot", null))));
  }
  static get is() { return "quirk-boomerang"; }
  static get originalStyleUrls() { return {
    "$": ["quirk-boomerang.css"]
  }; }
  static get styleUrls() { return {
    "$": ["quirk-boomerang.css"]
  }; }
  static get properties() { return {
    "moveCount": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "move-count",
      "reflect": false,
      "defaultValue": "1"
    },
    "totalElements": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "total-elements",
      "reflect": false,
      "defaultValue": "0"
    },
    "displayCount": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "| { small: string, medium: string, large: string }\n    | string | number",
        "resolved": "number | string | { small: string; medium: string; large: string; }",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "display-count",
      "reflect": false,
      "defaultValue": "{ small: \"1\", medium: \"2\", large: \"4\" }"
    },
    "moveButtonInaccessibleBehaviour": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "\"disable\" | \"hide\"",
        "resolved": "\"disable\" | \"hide\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "move-button-inaccessible-behaviour",
      "reflect": false,
      "defaultValue": "\"disable\""
    }
  }; }
  static get states() { return {
    "lastMovedElement": {},
    "moveDirection": {},
    "visibleMoveButton": {}
  }; }
  static get methods() { return {
    "moveQuirk": {
      "complexType": {
        "signature": "(isMoveForward: boolean | undefined, moveElementIndex?: number | undefined) => Promise<void>",
        "parameters": [{
            "tags": [],
            "text": ""
          }, {
            "tags": [],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "quirkEl"; }
}
