import { Component, h, Prop, State, Element } from "@stencil/core";
import { HoverEvent } from "../../utils/events/hover";
export class SpecialCard {
  constructor() {
    this.width = "auto";
    this.height = "auto";
    this.cardTitle = "";
    this.cardSubtitle = "";
    this.elevation = 2;
    this.hoverElevation = 0;
    this.showHeader = false;
    this.borderRadius = "0.25rem";
    this.isHover = false;
    this.hoverEvent = new HoverEvent((isHover) => { this.isHover = isHover; });
  }
  get specialCardContainerEl() {
    return this.el.querySelector('.special-card-container');
  }
  componentDidLoad() {
    this.hoverEvent.observe(this.specialCardContainerEl);
  }
  disconnectedCallback() {
    this.hoverEvent.stop(this.specialCardContainerEl);
  }
  render() {
    var _a, _b;
    return (h("div", { class: `special-card-container one-for-all-elevation-${this.isHover && this.hoverElevation ? this.hoverElevation : this.elevation}`, style: {
        width: this.width,
        height: this.height,
        borderRadius: this.borderRadius,
      } },
      h("div", { class: "special-card" },
        h("slot", { name: "header" },
          h("div", { class: {
              "special-card-header": true,
              "special-card-header--has-title": ((_a = this.cardTitle) === null || _a === void 0 ? void 0 : _a.length) > 0,
              "special-card-header--has-subtitle": ((_b = this.cardSubtitle) === null || _b === void 0 ? void 0 : _b.length) > 0
            } },
            h("slot", { name: "header-content" },
              h("h2", { class: "special-card-header__title" }, this.cardTitle),
              h("div", { class: "special-card-header__subtitle" }, this.cardSubtitle)))),
        h("slot", { name: "body" },
          h("div", { class: "special-card-body" },
            h("slot", null))),
        h("slot", { name: "footer" },
          h("div", { class: "special-card-footer" },
            h("slot", { name: "footer-content" }))))));
  }
  static get is() { return "special-card"; }
  static get originalStyleUrls() { return {
    "$": ["special-card.css"]
  }; }
  static get styleUrls() { return {
    "$": ["special-card.css"]
  }; }
  static get properties() { return {
    "width": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "width",
      "reflect": false,
      "defaultValue": "\"auto\""
    },
    "height": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "height",
      "reflect": false,
      "defaultValue": "\"auto\""
    },
    "cardTitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "card-title",
      "reflect": false,
      "defaultValue": "\"\""
    },
    "cardSubtitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "card-subtitle",
      "reflect": false,
      "defaultValue": "\"\""
    },
    "elevation": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "elevation",
      "reflect": false,
      "defaultValue": "2"
    },
    "hoverElevation": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "hover-elevation",
      "reflect": false,
      "defaultValue": "0"
    },
    "showHeader": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "show-header",
      "reflect": false,
      "defaultValue": "false"
    },
    "borderRadius": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "border-radius",
      "reflect": false,
      "defaultValue": "\"0.25rem\""
    }
  }; }
  static get states() { return {
    "isHover": {}
  }; }
  static get elementRef() { return "el"; }
}
