import { Component, h, Prop, State, Element } from "@stencil/core";
import { HoverEvent } from "../../utils/events/hover";
import { Ripple } from "../../utils/animations/ripple";
export class ZeroGravityButton {
  constructor() {
    this.ripple = true;
    this.elevation = 2;
    this.overlap = false;
    this.hoverElevation = 0;
    this.variant = "round";
    this.color = "primary";
    this.size = "large";
    this.radius = this.variant.toLowerCase() === "round" ? "50%" : "26px";
    this.position = "custom";
    this.isHover = false;
    this.hoverEvent = new HoverEvent((isHover) => {
      this.isHover = isHover;
    });
  }
  get ZeroGravityButtonEl() {
    return this.el.querySelector(".zero-gravity-button");
  }
  componentDidLoad() {
    this.hoverEvent.observe(this.ZeroGravityButtonEl);
    Ripple.observe(this.ZeroGravityButtonEl);
  }
  disconnectedCallback() {
    this.hoverEvent.stop(this.ZeroGravityButtonEl);
    Ripple.destroy(this.ZeroGravityButtonEl);
  }
  render() {
    return (h("button", { class: `zero-gravity-button one-for-all-ripple size-${this.size.toLowerCase()} one-for-all-elevation-${this.isHover && this.hoverElevation
        ? this.hoverElevation
        : this.elevation} color-${this.color.toLowerCase()} variant-${this.variant.toLowerCase()} ${this.position.toLowerCase()} ${this.overlap ? "overlap" : ""}`, type: "button", style: { borderRadius: this.radius } },
      h("slot", null)));
  }
  static get is() { return "zero-gravity-button"; }
  static get originalStyleUrls() { return {
    "$": ["zero-gravity-button.css"]
  }; }
  static get styleUrls() { return {
    "$": ["zero-gravity-button.css"]
  }; }
  static get properties() { return {
    "ripple": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "ripple",
      "reflect": false,
      "defaultValue": "true"
    },
    "elevation": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "elevation",
      "reflect": false,
      "defaultValue": "2"
    },
    "overlap": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "overlap",
      "reflect": false,
      "defaultValue": "false"
    },
    "hoverElevation": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "hover-elevation",
      "reflect": false,
      "defaultValue": "0"
    },
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "\"round\" | \"extended\"",
        "resolved": "\"extended\" | \"round\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "variant",
      "reflect": false,
      "defaultValue": "\"round\""
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "\"primary\" | \"secondary\"",
        "resolved": "\"primary\" | \"secondary\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "color",
      "reflect": false,
      "defaultValue": "\"primary\""
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "\"small\" | \"medium\" | \"large\"",
        "resolved": "\"large\" | \"medium\" | \"small\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "\"large\""
    },
    "radius": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "radius",
      "reflect": false,
      "defaultValue": "this.variant.toLowerCase() === \"round\" ? \"50%\" : \"26px\""
    },
    "position": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "| \"custom\"\n    | \"top-left\"\n    | \"top-center\"\n    | \"top-right\"\n    | \"center-left\"\n    | \"center-right\"\n    | \"bottom-left\"\n    | \"bottom-center\"\n    | \"bottom-right\"",
        "resolved": "\"bottom-center\" | \"bottom-left\" | \"bottom-right\" | \"center-left\" | \"center-right\" | \"custom\" | \"top-center\" | \"top-left\" | \"top-right\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "position",
      "reflect": false,
      "defaultValue": "\"custom\""
    }
  }; }
  static get states() { return {
    "isHover": {}
  }; }
  static get elementRef() { return "el"; }
}
